@@ -4,37 +4,35 @@ Test connection config.
 """
 
 from __future__ import with_statement
-from os import path, makedirs, environ
-import shutil
+from os import path, environ
+import tempfile
+
+import pytest
 
 from pymssql import _mssql
 
-from .helpers import tmpdir, skip_test, mssql_server_required
-config_dump_path = path.join(tmpdir, 'freetds-config-dump.txt')
-
-def setup_module():
-    if not path.isdir(tmpdir):
-        makedirs(tmpdir)
-
-@mssql_server_required
+@pytest.mark.mssql_server_required
 class TestConfig(object):
     def connect(self, **kwargs):
-        environ['TDSDUMPCONFIG'] = config_dump_path
-        try:
-            _mssql.connect(**kwargs)
-            assert False
-        except _mssql.MSSQLDriverException as e:
-            # we get this when the name of the server is not valid
-            if 'Connection to the database failed' not in str(e):
-                raise
-        except _mssql.MSSQLDatabaseException as e:
-            # we get this when the name or IP can be obtained but the connection
-            # can not be made
-            if e.args[0][0] != 20009:
-                raise
-        with open(config_dump_path, 'r') as fh:
-            return fh.read()
+        with tempfile.TemporaryDirectory() as tmpdir:
+            config_dump_path = path.join(tmpdir, 'freetds-config-dump.txt')
+            environ['TDSDUMPCONFIG'] = config_dump_path
+            try:
+                _mssql.connect(**kwargs)
+                assert False
+            except _mssql.MSSQLDriverException as e:
+                # we get this when the name of the server is not valid
+                if 'Connection to the database failed' not in str(e):
+                    raise
+            except _mssql.MSSQLDatabaseException as e:
+                # we get this when the name or IP can be obtained but the connection
+                # can not be made
+                if e.args[0][0] != 20009:
+                    raise
+            with open(config_dump_path, 'r') as fh:
+                return fh.read()
 
+    @pytest.mark.slow
     def test_config_values(self):
         config_dump = self.connect(
             server='dontnameyourserverthis',
@@ -51,6 +49,7 @@ class TestConfig(object):
         assert 'major_version = 7' in config_dump
         assert 'minor_version = 1' in config_dump
 
+    @pytest.mark.slow
     def test_tds_protocol_version_42(self):
         config_dump = self.connect(
             server='dontnameyourserverthis',
@@ -59,6 +58,7 @@ class TestConfig(object):
         assert 'major_version = 4' in config_dump
         assert 'minor_version = 2' in config_dump
 
+    @pytest.mark.slow
     def test_tds_protocol_version_70(self):
         config_dump = self.connect(
             server='dontnameyourserverthis',
@@ -67,6 +67,7 @@ class TestConfig(object):
         assert 'major_version = 7' in config_dump
         assert 'minor_version = 0' in config_dump
 
+    @pytest.mark.slow
     def test_tds_protocol_version_71(self):
         config_dump = self.connect(
             server='dontnameyourserverthis',
@@ -75,6 +76,7 @@ class TestConfig(object):
         assert 'major_version = 7' in config_dump
         assert 'minor_version = 1' in config_dump
 
+    @pytest.mark.slow
     def test_tds_protocol_version_80(self):
         # follow-up: turns out 8.0 was erroneous.  MS named the new protocol
         # 7.1 instead of 8.0, so FreeTDS will accept 8.0 but shows as 7.1.
@@ -89,6 +91,7 @@ class TestConfig(object):
         assert 'major_version = 7' in config_dump
         assert 'minor_version = 1' in config_dump
 
+    @pytest.mark.slow
     def test_tds_protocol_version_72(self):
         config_dump = self.connect(
             server='dontnameyourserverthis',
