@@ -7,11 +7,13 @@ from __future__ import with_statement
 from os import path, makedirs, environ
 import re
 import unittest
+import tempfile
+
 import pytest
 
 from pymssql import _mssql
 
-from .helpers import config, skip_test, mssqlconn, mssql_server_required
+from .helpers import config, mssqlconn
 server = config.server
 username = config.user
 password = config.password
@@ -20,23 +22,18 @@ port = config.port
 ipaddress = config.ipaddress
 instance = config.instance
 
-cdir = path.dirname(__file__)
-tmpdir = path.join(cdir, 'tmp')
-config_dump_path = path.join(tmpdir, 'freetds-config-dump.txt')
-dump_path = path.join(tmpdir, 'freetds-dump.txt')
 
-def setup_module():
-    if not path.isdir(tmpdir):
-        makedirs(tmpdir)
-
-@mssql_server_required
+@pytest.mark.mssql_server_required
 class TestCons(unittest.TestCase):
     def connect(self, **kwargs):
-        environ['TDSDUMPCONFIG'] = config_dump_path
-        environ['TDSDUMP'] = dump_path
-        _mssql.connect(**kwargs)
-        with open(config_dump_path, 'r') as fh:
-            return fh.read()
+        with tempfile.TemporaryDirectory() as tmpdir:
+            config_dump_path = path.join(tmpdir, 'freetds-config-dump.txt')
+            dump_path = path.join(tmpdir, 'freetds-dump.txt')
+            environ['TDSDUMPCONFIG'] = config_dump_path
+            environ['TDSDUMP'] = dump_path
+            _mssql.connect(**kwargs)
+            with open(config_dump_path, 'r') as fh:
+                return fh.read()
 
     def test_connection_by_dns_name(self):
         cdump = self.connect(server=server, port=port, user=username, password=password)
@@ -78,7 +75,7 @@ class TestCons(unittest.TestCase):
 
     def test_instance(self):
         if not instance:
-            skip_test()
+            pytest.skip()
         server_join = r'%s\%s' % (server, instance)
         cdump = self.connect(server=server_join, user=username, password=password)
         dump_server_name = re.search('server_name = (\\S+)', cdump).groups()[0]
@@ -125,6 +122,7 @@ class TestCons(unittest.TestCase):
         conn.close()
 
 
+@pytest.mark.slow
 class TestFailedConnection(unittest.TestCase):
 
     @pytest.mark.xfail(strict=False, reason="Could timeout, or fail with different error messages")
