@@ -14,7 +14,7 @@ from pymssql import _mssql
 
 import pytest
 
-from .helpers import mssqlconn, pymssqlconn, eq_, skip_test, get_sql_server_version, mssql_server_required
+from .helpers import mssqlconn, pymssqlconn
 
 FIXED_TYPES = (
     'BigInt',
@@ -38,7 +38,7 @@ VARIABLE_TYPES = (
     ('Text', None)  # Leave this one in the last position in case it fails (see https://code.google.com/p/pymssql/issues/detail?id=113#c2)
 )
 
-@mssql_server_required
+@pytest.mark.mssql_server_required
 class TestFixedTypeConversion(unittest.TestCase):
 
     def setUp(self):
@@ -83,7 +83,7 @@ class TestFixedTypeConversion(unittest.TestCase):
         proc.bind(input, _mssql.SQLINT8, '@ibigint')
         proc.bind(None, _mssql.SQLINT8, '@obigint', output=True)
         proc.execute()
-        eq_(input, proc.parameters['@obigint'])
+        self.assertEqual(input, proc.parameters['@obigint'])
 
     def testBigIntPymssql(self):
         """Same as testBigInt above but from pymssql. Uses pymssql.output class."""
@@ -96,11 +96,11 @@ class TestFixedTypeConversion(unittest.TestCase):
         in_val = 123456789
         cursor = self.pymssql.cursor()
         retval = cursor.callproc('pymssqlTestBigInt', [in_val, pymssql.output(py_type)])
-        eq_(in_val, retval[1])
+        self.assertEqual(in_val, retval[1])
 
         in_val = 2147483647
         retval = cursor.callproc('pymssqlTestBigInt', [in_val, pymssql.output(py_type)])
-        eq_(in_val, retval[1])
+        self.assertEqual(in_val, retval[1])
 
     def testBit(self):
         input = True
@@ -108,7 +108,7 @@ class TestFixedTypeConversion(unittest.TestCase):
         proc.bind(input, _mssql.SQLBITN, '@ibit')
         proc.bind(False, _mssql.SQLBITN, '@obit', output=True)
         proc.execute()
-        eq_(input, proc.parameters['@obit'])
+        self.assertEqual(input, proc.parameters['@obit'])
 
     def testDateTime(self):
         input = datetime.datetime(2009, 8, 27, 15, 28, 38)
@@ -116,7 +116,7 @@ class TestFixedTypeConversion(unittest.TestCase):
         proc.bind(input, _mssql.SQLDATETIME, '@idatetime')
         proc.bind(None, _mssql.SQLDATETIME, '@odatetime', output=True)
         proc.execute()
-        eq_(input, proc.parameters['@odatetime'])
+        self.assertEqual(input, proc.parameters['@odatetime'])
 
     def testDecimal(self):
         input = decimal.Decimal('5.12345')
@@ -125,8 +125,8 @@ class TestFixedTypeConversion(unittest.TestCase):
         proc.bind(input, _mssql.SQLDECIMAL, '@idecimal')
         proc.bind(output, _mssql.SQLDECIMAL, '@odecimal', output=True, max_length=6)
         proc.execute()
-        eq_(input, proc.parameters['@odecimal'])
-        eq_(str(input), str(proc.parameters['@odecimal']))
+        self.assertEqual(input, proc.parameters['@odecimal'])
+        self.assertEqual(str(input), str(proc.parameters['@odecimal']))
 
     def testDecimal2(self):
         input = decimal.Decimal('6.23456')
@@ -135,8 +135,8 @@ class TestFixedTypeConversion(unittest.TestCase):
         proc.bind(input, _mssql.SQLDECIMAL, '@idecimal')
         proc.bind(output, _mssql.SQLDECIMAL, '@odecimal', output=True, max_length=6)
         proc.execute()
-        eq_(input, proc.parameters['@odecimal'])
-        eq_(str(input), str(proc.parameters['@odecimal']))
+        self.assertEqual(input, proc.parameters['@odecimal'])
+        self.assertEqual(str(input), str(proc.parameters['@odecimal']))
 
     def testDecimal3(self):
         output = decimal.Decimal('0.00000')
@@ -145,8 +145,8 @@ class TestFixedTypeConversion(unittest.TestCase):
         proc.bind(input, _mssql.SQLDECIMAL, '@idecimal')
         proc.bind(output, _mssql.SQLDECIMAL, '@odecimal', output=True, max_length=6)
         proc.execute()
-        eq_(input, proc.parameters['@odecimal'])
-        eq_(str(input), str(proc.parameters['@odecimal']))
+        self.assertEqual(input, proc.parameters['@odecimal'])
+        self.assertEqual(str(input), str(proc.parameters['@odecimal']))
 
     def testDecimal4(self):
         output = decimal.Decimal('1.0000000')
@@ -155,8 +155,8 @@ class TestFixedTypeConversion(unittest.TestCase):
         proc.bind(input, _mssql.SQLDECIMAL, '@idecimal')
         proc.bind(output, _mssql.SQLDECIMAL, '@odecimal', output=True, max_length=15)
         proc.execute()
-        eq_(input, proc.parameters['@odecimal'])
-        eq_(str(input), str(proc.parameters['@odecimal']))
+        self.assertEqual(input, proc.parameters['@odecimal'])
+        self.assertEqual(str(input), str(proc.parameters['@odecimal']))
 
     def testDecimal5(self):
         output = decimal.Decimal('1.000000000')
@@ -165,8 +165,8 @@ class TestFixedTypeConversion(unittest.TestCase):
         proc.bind(input, _mssql.SQLDECIMAL, '@idecimal')
         proc.bind(output, _mssql.SQLDECIMAL, '@odecimal', output=True, max_length=15)
         proc.execute()
-        eq_(input, proc.parameters['@odecimal'])
-        eq_(str(input), str(proc.parameters['@odecimal']))
+        self.assertEqual(input, proc.parameters['@odecimal'])
+        self.assertEqual(str(input), str(proc.parameters['@odecimal']))
 
     def testInt(self):
         input = 10056
@@ -174,7 +174,7 @@ class TestFixedTypeConversion(unittest.TestCase):
         proc.bind(input, _mssql.SQLINT4, '@iint')
         proc.bind(None, _mssql.SQLINT4, '@oint', output=True)
         proc.execute()
-        eq_(input, proc.parameters['@oint'])
+        self.assertEqual(input, proc.parameters['@oint'])
 
     def testMoney(self):
         input = decimal.Decimal('5.12')
@@ -182,7 +182,7 @@ class TestFixedTypeConversion(unittest.TestCase):
         proc.bind(input, _mssql.SQLMONEY, '@imoney')
         proc.bind(None, _mssql.SQLMONEY, '@omoney', output=True)
         proc.execute()
-        eq_(input, proc.parameters['@omoney'])
+        self.assertEqual(input, proc.parameters['@omoney'])
 
     def testNumeric(self):
         input = decimal.Decimal('5.12345')
@@ -191,8 +191,8 @@ class TestFixedTypeConversion(unittest.TestCase):
         proc.bind(input, _mssql.SQLNUMERIC, '@inumeric')
         proc.bind(output, _mssql.SQLNUMERIC, '@onumeric', output=True)
         proc.execute()
-        eq_(input, proc.parameters['@onumeric'])
-        eq_(str(input), str(proc.parameters['@onumeric']))
+        self.assertEqual(input, proc.parameters['@onumeric'])
+        self.assertEqual(str(input), str(proc.parameters['@onumeric']))
 
     def testSmallInt(self):
         input = 10056
@@ -200,7 +200,7 @@ class TestFixedTypeConversion(unittest.TestCase):
         proc.bind(input, _mssql.SQLINT2, '@ismallint')
         proc.bind(None, _mssql.SQLINT2, '@osmallint', output=True)
         proc.execute()
-        eq_(input, proc.parameters['@osmallint'])
+        self.assertEqual(input, proc.parameters['@osmallint'])
 
     def testTinyInt(self):
         input = 101
@@ -208,18 +208,18 @@ class TestFixedTypeConversion(unittest.TestCase):
         proc.bind(input, _mssql.SQLINT1, '@itinyint')
         proc.bind(None, _mssql.SQLINT1, '@otinyint', output=True)
         proc.execute()
-        eq_(input, proc.parameters['@otinyint'])
+        self.assertEqual(input, proc.parameters['@otinyint'])
 
     def testUuid(self):
         if os.environ.get('FREETDS_VERSION') != '0.91':
-            pytest.xfail("UNIQUEIDENTIFIER as a SP param doesn't work with FreeTDS >= 0.95")
+            pytest.skip("UNIQUEIDENTIFIER as a SP param doesn't work with FreeTDS >= 0.95")
         import uuid
         input = uuid.uuid4()
         proc = self.mssql.init_procedure('pymssqlTestUniqueIdentifier')
         proc.bind(input, _mssql.SQLUUID, '@iuniqueidentifier')
         proc.bind(None, _mssql.SQLUUID, '@ouniqueidentifier', output=True)
         proc.execute()
-        eq_(input, proc.parameters['@ouniqueidentifier'])
+        self.assertEqual(input, proc.parameters['@ouniqueidentifier'])
 
     def testReal(self):
         input = 3.14
@@ -238,7 +238,7 @@ class TestFixedTypeConversion(unittest.TestCase):
         assert abs(input - proc.parameters['@ofloat']) < 0.00001
 
 
-@mssql_server_required
+@pytest.mark.mssql_server_required
 class TestCallProcFancy(unittest.TestCase):
     # "Fancy" because we test some exotic cases like passing None or Unicode
     # strings to a called procedure
@@ -256,8 +256,8 @@ class TestCallProcFancy(unittest.TestCase):
                    N'%(str1)s ' + @some_arg + N' %(str2)s'
         END
         """ % {
-            'str1': u'\u0417\u0434\u0440\u0430\u0432\u0441\u0442\u0432\u0443\u0439',
-            'str2': u'\u041c\u0438\u0440',
+            'str1': 'Здравствуй',
+            'str2': 'Мир',
         }
         sql = sql.encode('utf-8')
 
@@ -274,13 +274,9 @@ class TestCallProcFancy(unittest.TestCase):
             'someProcWithOneParam',
             (None,))
 
-        # For some reason, fetchone doesn't work
-        # It raises "OperationalError: Statement not executed or executed statement has no resultset"
-        # a, b = cursor.fetchone()
-
-        for a, b in cursor:
-            eq_(a, None)
-            eq_(b, None)
+        a, b = cursor.fetchone()
+        self.assertEqual(a, None)
+        self.assertEqual(b, None)
 
     def testCallProcWithAsciiString(self):
         cursor = self.pymssql.cursor()
@@ -288,27 +284,19 @@ class TestCallProcFancy(unittest.TestCase):
             'someProcWithOneParam',
             ('hello',))
 
-        # For some reason, fetchone doesn't work
-        # It raises "OperationalError: Statement not executed or executed statement has no resultset"
-        # a, b = cursor.fetchone()
-
-        for a, b in cursor:
-            eq_(a, 'hello!')
-            eq_(b, u'\u0417\u0434\u0440\u0430\u0432\u0441\u0442\u0432\u0443\u0439 hello \u041c\u0438\u0440')
+        a, b = cursor.fetchone()
+        self.assertEqual(a, 'hello!')
+        self.assertEqual(b, 'Здравствуй hello Мир')
 
     def testCallProcWithUnicodeStringWithNoFunnyCharacters(self):
         cursor = self.pymssql.cursor()
         cursor.callproc(
             'someProcWithOneParam',
-            (u'hello',))
+            ('hello',))
 
-        # For some reason, fetchone doesn't work
-        # It raises "OperationalError: Statement not executed or executed statement has no resultset"
-        # a, b = cursor.fetchone()
-
-        for a, b in cursor:
-            eq_(a, u'hello!')
-            eq_(b, u'\u0417\u0434\u0440\u0430\u0432\u0441\u0442\u0432\u0443\u0439 hello \u041c\u0438\u0440')
+        a, b = cursor.fetchone()
+        self.assertEqual(a, 'hello!')
+        self.assertEqual(b, 'Здравствуй hello Мир')
 
     # This is failing for me - the Unicode params somehow gets rendered to a
     # blank string. I am not sure if this is another bug or a user error on my
@@ -318,68 +306,55 @@ class TestCallProcFancy(unittest.TestCase):
         cursor = self.pymssql.cursor()
         cursor.callproc(
             'someProcWithOneParam',
-            (u'\u0417\u0434\u0440\u0430\u0432\u0441\u0442\u0432\u0443\u0439',))  # Russian string
+            ('Здравствуй',))  # Russian string
 
-        # For some reason, fetchone doesn't work
-        # It raises "OperationalError: Statement not executed or executed statement has no resultset"
-        # a, b = cursor.fetchone()
-
-        # This test fails with FreeTDS 0.91 (and probably older versions)
-        # because they don't seem to encode the Unicode string properly.
-        # See http://code.google.com/p/pymssql/issues/detail?id=109
-        skip_test()
-
-        for a, b in cursor:
-            eq_(a, u'\u0417\u0434\u0440\u0430\u0432\u0441\u0442\u0432\u0443\u0439!')
-            eq_(b, u'\u0417\u0434\u0440\u0430\u0432\u0441\u0442\u0432\u0443\u0439 \u0417\u0434\u0440\u0430\u0432\u0441\u0442\u0432\u0443\u0439 \u041c\u0438\u0440')
+        a, b = cursor.fetchone()
+        self.assertEqual(a, 'Здравствуй!')
+        self.assertEqual(b, 'Здравствуй Здравствуй Мир')
 
     def testExecuteWithNone(self):
         cursor = self.pymssql.cursor()
         cursor.execute(
-            u'someProcWithOneParam %s',
+            'someProcWithOneParam %s',
             (None,))
 
         a, b = cursor.fetchone()
-
-        eq_(a, None)
-        eq_(b, None)
+        self.assertEqual(a, None)
+        self.assertEqual(b, None)
 
     def testExecuteWithAsciiString(self):
         cursor = self.pymssql.cursor()
         cursor.execute(
-            u'someProcWithOneParam %s',
+            'someProcWithOneParam %s',
             ('hello',))
 
         a, b = cursor.fetchone()
-
-        eq_(a, 'hello!')
-        eq_(b, u'\u0417\u0434\u0440\u0430\u0432\u0441\u0442\u0432\u0443\u0439 hello \u041c\u0438\u0440')
+        self.assertEqual(a, 'hello!')
+        self.assertEqual(b, 'Здравствуй hello Мир')
 
     def testExecuteWithUnicodeStringWithNoFunnyCharacters(self):
         cursor = self.pymssql.cursor()
         cursor.execute(
-            u'someProcWithOneParam %s',
-            (u'hello',))
+            'someProcWithOneParam %s',
+            ('hello',))
 
         a, b = cursor.fetchone()
-
-        eq_(a, u'hello!')
-        eq_(b, u'\u0417\u0434\u0440\u0430\u0432\u0441\u0442\u0432\u0443\u0439 hello \u041c\u0438\u0440')
+        self.assertEqual(a, 'hello!')
+        self.assertEqual(b, 'Здравствуй hello Мир')
 
     def testExecuteWithUnicodeWithRussianCharacters(self):
         cursor = self.pymssql.cursor()
         cursor.execute(
-            u'someProcWithOneParam %s',
-            (u'\u0417\u0434\u0440\u0430\u0432\u0441\u0442\u0432\u0443\u0439',))  # Russian string
+            'someProcWithOneParam %s',
+            ('Здравствуй',))  # Russian string
 
         a, b = cursor.fetchone()
-
-        eq_(a, u'\u0417\u0434\u0440\u0430\u0432\u0441\u0442\u0432\u0443\u0439!')
-        eq_(b, u'\u0417\u0434\u0440\u0430\u0432\u0441\u0442\u0432\u0443\u0439 \u0417\u0434\u0440\u0430\u0432\u0441\u0442\u0432\u0443\u0439 \u041c\u0438\u0440')
+        self.assertEqual(a, 'Здравствуй!')
+        self.assertEqual(b, 'Здравствуй Здравствуй Мир')
 
 
 
-@mssql_server_required
+@pytest.mark.mssql_server_required
 class TestStringTypeConversion(unittest.TestCase):
 
     def setUp(self):
@@ -419,7 +394,7 @@ class TestStringTypeConversion(unittest.TestCase):
         proc.bind(input, _mssql.SQLCHAR, '@ichar')
         proc.bind(None, _mssql.SQLCHAR, '@ochar', output=True, max_length=4)
         proc.execute()
-        eq_(input, proc.parameters['@ochar'])
+        self.assertEqual(input, proc.parameters['@ochar'])
 
     def testText(self):
         input = 'test'
@@ -427,7 +402,7 @@ class TestStringTypeConversion(unittest.TestCase):
         proc.bind(input, _mssql.SQLTEXT, '@itext')
         proc.bind(None, _mssql.SQLVARCHAR, '@otext', output=True)
         proc.execute()
-        eq_(input, proc.parameters['@otext'])
+        self.assertEqual(input, proc.parameters['@otext'])
 
     def testVarChar(self):
         input = 'test'
@@ -435,7 +410,7 @@ class TestStringTypeConversion(unittest.TestCase):
         proc.bind(input, _mssql.SQLVARCHAR, '@ivarchar')
         proc.bind(None, _mssql.SQLVARCHAR, '@ovarchar', output=True)
         proc.execute()
-        eq_(input, proc.parameters['@ovarchar'])
+        self.assertEqual(input, proc.parameters['@ovarchar'])
 
     def testVarBinary(self):
         def check_conversion(input, output_type):
@@ -443,8 +418,8 @@ class TestStringTypeConversion(unittest.TestCase):
             proc.bind(input, _mssql.SQLVARBINARY, '@ivarbinary')
             proc.bind(None, _mssql.SQLVARBINARY, '@ovarbinary', output=True)
             proc.execute()
-            eq_(input, proc.parameters['@ovarbinary'])
-            eq_(output_type, type(proc.parameters['@ovarbinary']))
+            self.assertEqual(input, proc.parameters['@ovarbinary'])
+            self.assertEqual(output_type, type(proc.parameters['@ovarbinary']))
 
         if sys.version_info[0] == 3:
             check_conversion(bytes(b'\xDE\xAD\xBE\xEF'), bytes)
@@ -461,7 +436,7 @@ class TestStringTypeConversion(unittest.TestCase):
                 assert 'value can only be str or bytearray' == str(exc_info.value)
 
 
-@mssql_server_required
+@pytest.mark.mssql_server_required
 class TestFloatTypeConversion(unittest.TestCase):
     def setUp(self):
         self.mssql = mssqlconn()
@@ -514,7 +489,7 @@ class TestFloatTypeConversion(unittest.TestCase):
         a = next(cursor)
         assert abs(a[0] - 5.44451787074e+39) < 0.000001
 
-@mssql_server_required
+@pytest.mark.mssql_server_required
 class TestErrorInSP(unittest.TestCase):
 
     def setUp(self):
@@ -557,7 +532,7 @@ class TestErrorInSP(unittest.TestCase):
             self.assertTrue(isinstance(e,  pymssql.DatabaseError))
 
 
-@mssql_server_required
+@pytest.mark.mssql_server_required
 class TestSPWithQueryResult(unittest.TestCase):
 
     SP_NAME = 'SPWithAQuery'
@@ -586,13 +561,9 @@ class TestSPWithQueryResult(unittest.TestCase):
             self.SP_NAME,
             ('hello',))
 
-        # For some reason, fetchone doesn't work
-        # It raises "OperationalError: Statement not executed or executed statement has no resultset"
-        #a, b = cursor.fetchone()
-
-        for a, b in cursor:
-            eq_(a, 'hello!')
-            eq_(b, 'hello!!')
+        a, b = cursor.fetchone()
+        self.assertEqual(a, 'hello!')
+        self.assertEqual(b, 'hello!!')
 
     def test_mssql(self):
         proc = self.mssql.init_procedure(self.SP_NAME)
@@ -600,4 +571,4 @@ class TestSPWithQueryResult(unittest.TestCase):
         proc.execute()
 
         for row_dict in self.mssql:
-            eq_(row_dict, {0: 'hello!', 1: 'hello!!'})
+            self.assertEqual(row_dict, {0: 'hello!', 1: 'hello!!'})
